pub struct OtaManifest {
pub app_id: String,
pub updates: Vec<OtaUpdate>,
}Expand description
Manifest listing available OTA updates for an app.
Fields
app_id: Stringupdates: Vec<OtaUpdate>Implementations
Sourceimpl OtaManifest
impl OtaManifest
pub fn new(app_id: impl Into<String>) -> Self
Sourcepub fn latest_update(
&self,
current_native: &BundleVersion,
platform: BuildTarget,
) -> Option<&OtaUpdate>
pub fn latest_update( &self, current_native: &BundleVersion, platform: BuildTarget, ) -> Option<&OtaUpdate>
Find the latest compatible update for the given native version and platform.
Sourcepub fn has_update_for(
&self,
current_bundle: &BundleVersion,
current_native: &BundleVersion,
platform: BuildTarget,
) -> bool
pub fn has_update_for( &self, current_bundle: &BundleVersion, current_native: &BundleVersion, platform: BuildTarget, ) -> bool
Check if an update is available for the given version.