pub fn snapshot_tree(
tree: &ShadowTree,
layout_engine: &LayoutEngine,
) -> Option<NodeSnapshot>Expand description
Build a full tree snapshot starting from the root.
pub fn snapshot_tree(
tree: &ShadowTree,
layout_engine: &LayoutEngine,
) -> Option<NodeSnapshot>Build a full tree snapshot starting from the root.