pub struct PluginDescriptor {Show 14 fields
pub name: String,
pub version: PluginVersion,
pub description: String,
pub author: String,
pub license: String,
pub homepage: Option<String>,
pub repository: Option<String>,
pub category: PluginCategory,
pub capabilities: Vec<PluginCapability>,
pub supported_platforms: Vec<BuildTarget>,
pub min_engine_version: PluginVersion,
pub dependencies: Vec<PluginDependency>,
pub js_package: Option<String>,
pub keywords: Vec<String>,
}Expand description
Full descriptor for a plugin package.
Fields
name: Stringversion: PluginVersiondescription: Stringlicense: Stringhomepage: Option<String>repository: Option<String>category: PluginCategorycapabilities: Vec<PluginCapability>supported_platforms: Vec<BuildTarget>min_engine_version: PluginVersiondependencies: Vec<PluginDependency>js_package: Option<String>keywords: Vec<String>Implementations
Sourceimpl PluginDescriptor
impl PluginDescriptor
Sourcepub fn supports_platform(&self, target: &BuildTarget) -> bool
pub fn supports_platform(&self, target: &BuildTarget) -> bool
Check if this plugin supports the given platform.
Sourcepub fn is_compatible_with_engine(&self, engine_version: &PluginVersion) -> bool
pub fn is_compatible_with_engine(&self, engine_version: &PluginVersion) -> bool
Check if this plugin is compatible with the given engine version.
Sourcepub fn check_dependencies(
&self,
installed: &HashMap<String, PluginVersion>,
) -> Vec<String>
pub fn check_dependencies( &self, installed: &HashMap<String, PluginVersion>, ) -> Vec<String>
Check if all dependencies are satisfied by the given installed set.