IrCommand

Enum IrCommand 

pub enum IrCommand {
    CreateNode {
        id: NodeId,
        view_type: ViewType,
        props: HashMap<String, PropValue>,
        style: LayoutStyle,
    },
    UpdateProps {
        id: NodeId,
        diff: PropsDiff,
    },
    UpdateStyle {
        id: NodeId,
        style: LayoutStyle,
    },
    AppendChild {
        parent: NodeId,
        child: NodeId,
    },
    InsertBefore {
        parent: NodeId,
        child: NodeId,
        before: NodeId,
    },
    RemoveChild {
        parent: NodeId,
        child: NodeId,
    },
    SetRootNode {
        id: NodeId,
    },
}
A single command from the reconciler to the engine. Each React commit produces a batch of these commands.

Variants



CreateNode

Create a new node with initial props and style.

Fields

view_type: ViewType


UpdateProps

Update props on an existing node (only changed props).

Fields



UpdateStyle

Update layout style on an existing node.

Fields



AppendChild

Append a child to a parent (at the end).

Fields

parent: NodeId
child: NodeId


InsertBefore

Insert a child before another child.

Fields

parent: NodeId
child: NodeId
before: NodeId


RemoveChild

Remove a child from its parent (and destroy the subtree).

Fields

parent: NodeId
child: NodeId


SetRootNode

Set the root node of the tree.

Fields